import {
	Body,
	Controller,
	DefaultValuePipe,
	Delete,
	Get,
	HttpCode,
	HttpStatus,
	Param,
	ParseBoolPipe,
	ParseIntPipe,
	Post,
	Query,
	UseGuards,
} from "@nestjs/common";
import { ApiResponse, ApiTags } from "@nestjs/swagger";
import { AdminGuard } from "apps/backend/src/app/auth/auth.guard";
import { IMachinesTable } from "apps/backend/src/app/db/schema";
import {
	CreateMachineDto,
	TypeDto,
} from "apps/backend/src/app/machines/machines.dto";
import { MachinesService } from "apps/backend/src/app/machines/machines.service";

@ApiTags("Machines")
@Controller("machines")
export class MachinesController {
	constructor(private readonly machineService: MachinesService) {}

	@HttpCode(HttpStatus.OK)
	@Get("find")
	async findMany(
		@Query("limit", new DefaultValuePipe(20), ParseIntPipe) limit: number,
		@Query("offset", new DefaultValuePipe(0), ParseIntPipe) offset: number,
		@Query("search", new DefaultValuePipe("")) search: string,
	) {
		return await this.machineService.findMany(limit, offset, search);
	}

	@UseGuards(AdminGuard)
	@Post("new")
	async newMachine(@Body() body: CreateMachineDto) {
		return await this.machineService.create(body.machineName, body.machineType);
	}

	@HttpCode(HttpStatus.ACCEPTED)
	@UseGuards(AdminGuard)
	@Delete(":machineId")
	async deleteMachine(@Param("machineId") machineId: string) {}

	@HttpCode(HttpStatus.ACCEPTED)
	@UseGuards(AdminGuard)
	@Post("types/:machineId")
	async addTypeToMachine(
		@Param("machineId") machineId: string,
		@Body() body: TypeDto,
	) {
		return await this.machineService.addFileType(machineId, body.fileTypeId);
	}

	@HttpCode(HttpStatus.ACCEPTED)
	@UseGuards(AdminGuard)
	@Delete("types/:machineId")
	async remTypeToMachine(
		@Param("machineId") machineId: string,
		@Body() body: TypeDto,
	) {
		return await this.machineService.removeFileType(machineId, body.fileTypeId);
	}

	@HttpCode(HttpStatus.OK)
	@Get("types/:machineId")
	async getTypesOfMachine(@Param("machineId") machineId: string) {
		return await this.machineService.getFilesTypes(machineId);
	}

	@HttpCode(HttpStatus.OK)
	@Get("files/:machineId")
	async getFilesForMachine(
		@Query("limit", new DefaultValuePipe(20), ParseIntPipe) limit: number,
		@Query("offset", new DefaultValuePipe(0), ParseIntPipe) offset: number,
		@Query("search", new DefaultValuePipe("")) search: string,
		@Param("machineId") machineId: string,
	) {
		return this.machineService.findFilesForMachine(
			limit,
			offset,
			search,
			machineId,
		);
	}
}
