'use client';
import React from 'react';
import MultipleSelector, { Option } from '../ui/multiple-selector';
import { MachinesApi } from '../../requests/machines';
import { Loader } from 'lucide-react';
import IntrinsicAttributes = React.JSX.IntrinsicAttributes;

async function getMachines(value: string): Promise<Option[]> {
  try {
    const machines = await MachinesApi.get.all();
    console.log(machines.length);

    const filtered = machines.filter((machine) => machine.machineName && machine.machineName.toLowerCase().includes(value.toLowerCase()));
    console.log(filtered.length);

    const mapped = filtered.map((machine) => ({
      label: machine.machineName,
      value: machine.id,
    }));

    return mapped;
  } catch (error) {
    console.error('Erreur lors de la récupération des machines:', error);
    return [];
  }
}

export function MultipleMachinesSelector(fields: IntrinsicAttributes) {

  return (<MultipleSelector
    onSearch={async (value) => {
      const res = await getMachines(value);
      return res;
    }}
    triggerSearchOnFocus
    placeholder="Cliquez pour chercher."
    loadingIndicator={
      <div>
        <Loader className={"animate-spin h-4 w-4 mr-2"} />
        <p className="py-2 text-center text-lg leading-10 text-muted-foreground">Chargement...</p>
      </div>
    }
    emptyIndicator={
      <p
        className="w-full text-center text-lg leading-10 text-muted-foreground">
        Auccun résultats
      </p>
    }
  />);
};
