import { PaginationState } from "@tanstack/react-table";
import { IFile, IFilesResponse } from "../types/file";
import axios from 'axios';
import { IMachine } from 'apps/frontend/src/types/machine';

const API_URL = "http://localhost:3333/";
const PAGE_LIMIT = 10;

function getFullRoute(route: string) {
  return API_URL + route;
}

/**
 * Fetches a list of files from the server.
 *
 * @return {Promise<IMachine[]>} A promise that resolves to an IFilesResponse object containing the list of files.
 */
async function getMachines(): Promise<IMachine[]> {
  const response = await axios.get<IMachine[]>(getFullRoute("api/machines/find"), {
    params: {
      limit: -1,
      offset: 0,
    },
  });

  return response.data;
}

export const MachinesApi = {
  get: {
    all: getMachines
  }
}